@@ -5,6 +5,7 @@
 # CreateDate: 2022/10/28 15:52
 # Description:
 import dis
+import re
 import functools
 import logging
 import types
@@ -250,7 +251,7 @@ def match(name, condition_value_list: list, default=None):
     for condition, value in condition_value_list:
         if name == condition:
             return value
-    return default
+    return default or name
 
 
 _BUILTINS = {
@@ -292,6 +293,7 @@ _BUILTINS = {
     'Exception': Exception,
     'random': random,
     'match': match,
+    're': re,
 }
 
 
